@@ -27,12 +27,13 @@
 #include "CarlaBackendUtils.hpp"
 #include "CarlaBase64Utils.hpp"
 #include "ThreadSafeFFTW.hpp"
-#ifndef BUILD_BRIDGE
-# include "CarlaLogThread.hpp"
-#endif
 
 #include "water/files/File.h"
 
+#ifdef USING_JUCE
+# include "carla_juce/carla_juce.h"
+#endif
+
 #define CARLA_SAFE_ASSERT_WITH_LAST_ERROR_RETURN(cond, msg, ret) \
     if (! (cond)) {                                              \
         carla_stderr2("%s: " msg, __FUNCTION__);                 \
@@ -41,21 +42,6 @@
         return ret;                                              \
     }
 
-// --------------------------------------------------------------------------------------------------------------------
-
-#ifdef USING_JUCE
-static void carla_standalone_juce_init(void);
-static void carla_standalone_juce_idle(void);
-static void carla_standalone_juce_cleanup(void);
-# define carla_juce_init carla_standalone_juce_init
-# define carla_juce_idle carla_standalone_juce_idle
-# define carla_juce_cleanup carla_standalone_juce_cleanup
-# include "utils/JUCE.cpp"
-# undef carla_juce_init
-# undef carla_juce_idle
-# undef carla_juce_cleanup
-#endif
-
 // -------------------------------------------------------------------------------------------------------------------
 // Always return a valid string ptr for standalone functions
 
@@ -413,7 +399,7 @@ bool carla_engine_init(CarlaHostHandle handle, const char* driverName, const cha
 #endif
 
 #ifdef USING_JUCE
-    carla_standalone_juce_init();
+    CarlaJUCE::initialiseJuce_GUI();
 #endif
 
     CarlaHostStandalone& shandle((CarlaHostStandalone&)*handle);
@@ -450,7 +436,7 @@ bool carla_engine_init(CarlaHostHandle handle, const char* driverName, const cha
 
     if (engine->init(clientName))
     {
-#ifndef BUILD_BRIDGE
+#ifdef CARLA_CAN_USE_LOG_THREAD
         if (shandle.logThreadEnabled && std::getenv("CARLA_LOGS_DISABLED") == nullptr)
             shandle.logThread.init();
 #endif
@@ -463,7 +449,7 @@ bool carla_engine_init(CarlaHostHandle handle, const char* driverName, const cha
         shandle.engine = nullptr;
         delete engine;
 #ifdef USING_JUCE
-        carla_standalone_juce_cleanup();
+        CarlaJUCE::shutdownJuce_GUI();
 #endif
         return false;
     }
@@ -535,7 +521,7 @@ bool carla_engine_close(CarlaHostHandle handle)
     if (! closed)
         shandle.lastError = engine->getLastError();
 
-#ifndef BUILD_BRIDGE
+#ifdef CARLA_CAN_USE_LOG_THREAD
     shandle.logThread.stop();
 #endif
 
@@ -543,7 +529,7 @@ bool carla_engine_close(CarlaHostHandle handle)
     delete engine;
 
 #ifdef USING_JUCE
-    carla_standalone_juce_cleanup();
+    CarlaJUCE::shutdownJuce_GUI();
 #endif
     return closed;
 }
@@ -556,7 +542,7 @@ void carla_engine_idle(CarlaHostHandle handle)
 
 #ifdef USING_JUCE
     if (handle->isStandalone)
-        carla_standalone_juce_idle();
+        CarlaJUCE::idleJuce_GUI();
 #endif
 }
 
@@ -693,7 +679,7 @@ void carla_set_engine_callback(CarlaHostHandle handle, EngineCallbackFunc func,
         shandle.engineCallback    = func;
         shandle.engineCallbackPtr = ptr;
 
-#ifndef BUILD_BRIDGE
+#ifdef CARLA_CAN_USE_LOG_THREAD
         shandle.logThread.setCallback(func, ptr);
 #endif
     }
@@ -990,7 +976,9 @@ void carla_set_engine_option(CarlaHostHandle handle, EngineOption option, int va
 
 #ifndef BUILD_BRIDGE
         case CB::ENGINE_OPTION_DEBUG_CONSOLE_OUTPUT:
+#ifdef CARLA_CAN_USE_LOG_THREAD
             shandle.logThreadEnabled = (value != 0);
+#endif
             break;
 #endif
 
@@ -2403,7 +2391,7 @@ const char* carla_get_host_osc_url_udp(CarlaHostHandle handle)
 
 // --------------------------------------------------------------------------------------------------------------------
 
-#ifndef CARLA_PLUGIN_EXPORT
+#ifndef CARLA_PLUGIN_BUILD
 # define CARLA_PLUGIN_UI_CLASS_PREFIX Standalone
 # include "CarlaPluginUI.cpp"
 # undef CARLA_PLUGIN_UI_CLASS_PREFIX
@@ -2415,6 +2403,6 @@ const char* carla_get_host_osc_url_udp(CarlaHostHandle handle)
 # include "CarlaStateUtils.cpp"
 # include "utils/Information.cpp"
 # include "utils/Windows.cpp"
-#endif /* CARLA_PLUGIN_EXPORT */
+#endif /* CARLA_PLUGIN_BUILD */
 
 // --------------------------------------------------------------------------------------------------------------------
