@@ -1,6 +1,6 @@
 /*
  * Carla Plugin Host
- * Copyright (C) 2011-2021 Filipe Coelho <falktx@falktx.com>
+ * Copyright (C) 2011-2022 Filipe Coelho <falktx@falktx.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -15,9 +15,7 @@
  * For a full copy of the GNU General Public License see the doc/GPL.txt file.
  */
 
-#include "CarlaHost.h"
 #include "CarlaUtils.h"
-
 #include "CarlaString.hpp"
 
 #if defined(HAVE_FLUIDSYNTH) && !defined(BUILD_BRIDGE_ALTERNATIVE_ARCH)
@@ -34,8 +32,7 @@
 #endif
 
 #ifdef USING_JUCE
-# include "AppConfig.h"
-# include "juce_core/juce_core.h"
+# include "carla_juce/carla_juce.h"
 #endif
 
 #ifdef USING_RTAUDIO
@@ -74,11 +71,15 @@ const char* carla_get_complete_license_text()
 #endif
 #if defined(USING_JUCE) && JUCE_PLUGINHOST_VST3
         "<li>VST3 plugin support (using JUCE)</li>"
+#else
+        "<li>VST3 plugin support (using Travesty header files)</li>"
 #endif
 #if defined(USING_JUCE) && JUCE_PLUGINHOST_AU
         "<li>AU plugin support (using JUCE)</li>"
 #endif
 
+        "<li>JSFX plugin support (using ysfx)</li>"
+
         // Sample kit libraries
 #if defined(HAVE_FLUIDSYNTH) && !defined(BUILD_BRIDGE_ALTERNATIVE_ARCH)
         "<li>FluidSynth library v" FLUIDSYNTH_VERSION " for SF2/3 support</li>"
@@ -129,7 +130,7 @@ const char* carla_get_juce_version()
 #ifdef USING_JUCE
     if (retVersion.isEmpty())
     {
-        if (const char* const version = juce::SystemStats::getJUCEVersion().toRawUTF8())
+        if (const char* const version = CarlaJUCE::getVersion())
             retVersion = version+6;
         else
             retVersion = "Unknown";
@@ -188,6 +189,9 @@ const char* const* carla_get_supported_file_extensions()
         // SFZ
         "sfz",
 
+        // JSFX
+        "jsfx",
+
         // terminator
         nullptr
     };
@@ -220,7 +224,6 @@ const char* const* carla_get_supported_features()
 #endif
 #ifdef USING_JUCE
         "juce",
-        "vst3",
 # if defined(CARLA_OS_MAC)
         "au",
 # endif
