@@ -1,6 +1,6 @@
 /*
  * Carla JACK API for external applications
- * Copyright (C) 2016-2020 Filipe Coelho <falktx@falktx.com>
+ * Copyright (C) 2016-2022 Filipe Coelho <falktx@falktx.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,7 +23,7 @@ CARLA_BACKEND_USE_NAMESPACE
 
 static uint32_t gPortId = JackPortState::kPortIdOffsetUser;
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 jack_port_t* jack_port_register(jack_client_t* client, const char* port_name, const char* port_type,
                                 unsigned long flags, unsigned long buffer_size)
 {
@@ -136,7 +136,7 @@ jack_port_t* jack_port_register(jack_client_t* client, const char* port_name, co
     (void)buffer_size;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_unregister(jack_client_t* client, jack_port_t* port)
 {
     carla_debug("%s(%p, %p)", __FUNCTION__, client, port);
@@ -193,7 +193,7 @@ int jack_port_unregister(jack_client_t* client, jack_port_t* port)
     return EINVAL;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 void* jack_port_get_buffer(jack_port_t* port, jack_nframes_t)
 {
     JackPortState* const jport = (JackPortState*)port;
@@ -204,7 +204,7 @@ void* jack_port_get_buffer(jack_port_t* port, jack_nframes_t)
 
 // --------------------------------------------------------------------------------------------------------------------
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 jack_uuid_t jack_port_uuid(const jack_port_t* port)
 {
     carla_debug("%s(%p)", __FUNCTION__, port);
@@ -215,7 +215,7 @@ jack_uuid_t jack_port_uuid(const jack_port_t* port)
     return jport->uuid;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 const char* jack_port_name(const jack_port_t* port)
 {
     carla_debug("%s(%p)", __FUNCTION__, port);
@@ -226,7 +226,7 @@ const char* jack_port_name(const jack_port_t* port)
     return jport->fullname;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 const char* jack_port_short_name(const jack_port_t* port)
 {
     carla_debug("%s(%p)", __FUNCTION__, port);
@@ -237,7 +237,7 @@ const char* jack_port_short_name(const jack_port_t* port)
     return jport->name;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_flags(const jack_port_t* port)
 {
     carla_debug("%s(%p)", __FUNCTION__, port);
@@ -248,7 +248,7 @@ int jack_port_flags(const jack_port_t* port)
     return jport->flags;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 const char* jack_port_type(const jack_port_t* port)
 {
     carla_debug("%s(%p)", __FUNCTION__, port);
@@ -262,7 +262,7 @@ const char* jack_port_type(const jack_port_t* port)
     return jport->isMidi ? kMidiType : kAudioType;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 uint32_t jack_port_type_id(const jack_port_t* port)
 {
     carla_debug("%s(%p)", __FUNCTION__, port);
@@ -275,7 +275,7 @@ uint32_t jack_port_type_id(const jack_port_t* port)
 
 // --------------------------------------------------------------------------------------------------------------------
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_is_mine(const jack_client_t*, const jack_port_t* port)
 {
     const JackPortState* const jport = (const JackPortState*)port;
@@ -284,7 +284,7 @@ int jack_port_is_mine(const jack_client_t*, const jack_port_t* port)
     return jport->isSystem ? 0 : 1;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_connected(const jack_port_t* port)
 {
     const JackPortState* const jport = (const JackPortState*)port;
@@ -293,7 +293,7 @@ int jack_port_connected(const jack_port_t* port)
     return jport->isConnected ? 1 : 0;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_connected_to(const jack_port_t* port, const char* port_name)
 {
     carla_stderr2("%s(%p, %s) WIP", __FUNCTION__, port, port_name);
@@ -310,7 +310,7 @@ int jack_port_connected_to(const jack_port_t* port, const char* port_name)
 
 // --------------------------------------------------------------------------------------------------------------------
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_tie(jack_port_t* src, jack_port_t* dst)
 {
     carla_debug("%s(%p, %p)", __FUNCTION__, src, dst);
@@ -321,7 +321,7 @@ int jack_port_tie(jack_port_t* src, jack_port_t* dst)
     (void)dst;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_untie(jack_port_t* port)
 {
     carla_debug("%s(%p)", __FUNCTION__, port);
@@ -333,14 +333,14 @@ int jack_port_untie(jack_port_t* port)
 
 // --------------------------------------------------------------------------------------------------------------------
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_set_name(jack_port_t *port, const char *port_name)
 {
     carla_stderr2("%s(%p, %s)", __FUNCTION__, port, port_name);
     return ENOSYS;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_rename(jack_client_t* client, jack_port_t *port, const char *port_name)
 {
     carla_stderr2("%s(%p, %p, %s) WIP", __FUNCTION__, client, port, port_name);
@@ -376,21 +376,21 @@ int jack_port_rename(jack_client_t* client, jack_port_t *port, const char *port_
     return 0;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_set_alias(jack_port_t* port, const char* alias)
 {
     carla_stderr2("%s(%p, %s)", __FUNCTION__, port, alias);
     return ENOSYS;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_unset_alias(jack_port_t* port, const char* alias)
 {
     carla_stderr2("%s(%p, %s)", __FUNCTION__, port, alias);
     return ENOSYS;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_get_aliases(const jack_port_t*, char* const aliases[2])
 {
     *aliases[0] = '\0';
@@ -400,28 +400,28 @@ int jack_port_get_aliases(const jack_port_t*, char* const aliases[2])
 
 // --------------------------------------------------------------------------------------------------------------------
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_request_monitor(jack_port_t* port, int onoff)
 {
     carla_stderr2("%s(%p, %i)", __FUNCTION__, port, onoff);
     return ENOSYS;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_request_monitor_by_name(jack_client_t* client, const char* port_name, int onoff)
 {
     carla_stderr2("%s(%p, %s, %i)", __FUNCTION__, client, port_name, onoff);
     return ENOSYS;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_ensure_monitor(jack_port_t* port, int onoff)
 {
     carla_stderr2("%s(%p, %i)", __FUNCTION__, port, onoff);
     return ENOSYS;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_monitoring_input(jack_port_t* port)
 {
     carla_stderr2("%s(%p)", __FUNCTION__, port);
@@ -430,21 +430,21 @@ int jack_port_monitoring_input(jack_port_t* port)
 
 // --------------------------------------------------------------------------------------------------------------------
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_connect(jack_client_t* client, const char* a, const char* b)
 {
     carla_stderr2("%s(%p, %s. %s)", __FUNCTION__, client, a, b);
     return 0;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_disconnect(jack_client_t* client, const char* a, const char* b)
 {
     carla_stderr2("%s(%p, %s. %s)", __FUNCTION__, client, a, b);
     return 0;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_disconnect(jack_client_t* client, jack_port_t* port)
 {
     carla_stderr2("%s(%p, %p)", __FUNCTION__, client, port);
@@ -453,19 +453,19 @@ int jack_port_disconnect(jack_client_t* client, jack_port_t* port)
 
 // --------------------------------------------------------------------------------------------------------------------
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_name_size(void)
 {
     return STR_MAX;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 int jack_port_type_size(void)
 {
     return STR_MAX;
 }
 
-CARLA_EXPORT
+CARLA_PLUGIN_EXPORT
 size_t jack_port_type_get_buffer_size(jack_client_t* client, const char* port_type)
 {
     carla_debug("%s(%p, %s)", __FUNCTION__, client, port_type);
