@@ -2,15 +2,15 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2020 - Raw Material Software Limited
+   Copyright (c) 2022 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 6 End-User License
-   Agreement and JUCE Privacy Policy (both effective as of the 16th June 2020).
+   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
+   Agreement and JUCE Privacy Policy.
 
-   End User License Agreement: www.juce.com/juce-6-licence
+   End User License Agreement: www.juce.com/juce-7-licence
    Privacy Policy: www.juce.com/juce-privacy-policy
 
    Or: You may also use this code under the terms of the GPL v3 (see
@@ -23,10 +23,17 @@
   ==============================================================================
 */
 
-// Wow, those Steinberg guys really don't worry too much about compiler warnings.
-JUCE_BEGIN_IGNORE_WARNINGS_LEVEL_MSVC (0, 4505 4702)
+#pragma once
 
-JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wnon-virtual-dtor",
+#if JUCE_BSD && ! JUCE_CUSTOM_VST3_SDK
+ #error To build JUCE VST3 plug-ins on BSD you must use an external BSD-compatible VST3 SDK with JUCE_CUSTOM_VST3_SDK=1
+#endif
+
+// Wow, those Steinberg guys really don't worry too much about compiler warnings.
+JUCE_BEGIN_IGNORE_WARNINGS_LEVEL_MSVC (0, 4505 4702 6011 6031 6221 6386 6387 6330 6001 28199)
+
+JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wdeprecated-copy-dtor",
+                                     "-Wnon-virtual-dtor",
                                      "-Wreorder",
                                      "-Wunsequenced",
                                      "-Wint-to-pointer-cast",
@@ -57,7 +64,10 @@ JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wnon-virtual-dtor",
                                      "-Wextra",
                                      "-Wclass-memaccess",
                                      "-Wmissing-prototypes",
-                                     "-Wtype-limits")
+                                     "-Wtype-limits",
+                                     "-Wcpp",
+                                     "-W#warnings",
+                                     "-Wmaybe-uninitialized")
 
 #undef DEVELOPMENT
 #define DEVELOPMENT 0  // This avoids a Clang warning in Steinberg code about unused values
@@ -97,6 +107,8 @@ JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wnon-virtual-dtor",
  #include <public.sdk/source/common/memorystream.h>
  #include <public.sdk/source/vst/vsteditcontroller.h>
  #include <public.sdk/source/vst/vstpresetfile.h>
+
+ #include "pslextensions/ipslviewembedding.h"
 #else
  // needed for VST_VERSION
  #include <pluginterfaces/vst/vsttypes.h>
@@ -108,6 +120,14 @@ JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wnon-virtual-dtor",
  #include <base/source/fstreamer.cpp>
  #include <base/source/fstring.cpp>
 
+ // The following shouldn't leak from fstring.cpp
+ #undef stricmp
+ #undef strnicmp
+ #undef snprintf
+ #undef vsnprintf
+ #undef snwprintf
+ #undef vsnwprintf
+
  #if VST_VERSION >= 0x030608
   #include <base/thread/source/flock.cpp>
   #include <pluginterfaces/base/coreiids.cpp>
@@ -139,6 +159,8 @@ JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wnon-virtual-dtor",
   #include <public.sdk/source/vst/hosting/pluginterfacesupport.cpp>
  #endif
 
+ #include "pslextensions/ipslviewembedding.h"
+
 //==============================================================================
 namespace Steinberg
 {
@@ -156,10 +178,17 @@ namespace Steinberg
     DEF_CLASS_IID (IPlugFrame)
     DEF_CLASS_IID (IPlugViewContentScaleSupport)
 
-   #if JUCE_LINUX
+   #if JUCE_LINUX || JUCE_BSD
     DEF_CLASS_IID (Linux::IRunLoop)
+    DEF_CLASS_IID (Linux::IEventHandler)
    #endif
 }
+
+namespace Presonus
+{
+    DEF_CLASS_IID (IPlugInViewEmbedding)
+}
+
 #endif // JUCE_VST3HEADERS_INCLUDE_HEADERS_ONLY
 
 JUCE_END_IGNORE_WARNINGS_MSVC
@@ -212,3 +241,7 @@ JUCE_END_IGNORE_WARNINGS_GCC_LIKE
 #undef DEF_CLASS2
 #undef DEF_CLASS_W
 #undef END_FACTORY
+
+#ifdef atomic_thread_fence
+ #undef atomic_thread_fence
+#endif
