@@ -2,15 +2,15 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2020 - Raw Material Software Limited
+   Copyright (c) 2022 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 6 End-User License
-   Agreement and JUCE Privacy Policy (both effective as of the 16th June 2020).
+   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
+   Agreement and JUCE Privacy Policy.
 
-   End User License Agreement: www.juce.com/juce-6-licence
+   End User License Agreement: www.juce.com/juce-7-licence
    Privacy Policy: www.juce.com/juce-privacy-policy
 
    Or: You may also use this code under the terms of the GPL v3 (see
@@ -26,6 +26,8 @@
 namespace juce
 {
 
+class AudioProcessor;
+
 //==============================================================================
 /** An abstract base class for parameter objects that can be added to an
     AudioProcessor.
@@ -37,7 +39,58 @@ namespace juce
 class JUCE_API  AudioProcessorParameter
 {
 public:
-    AudioProcessorParameter() noexcept;
+    AudioProcessorParameter() noexcept = default;
+
+    /** The version hint supplied to this constructor is used in Audio Unit plugins to aid ordering
+        parameter identifiers when JUCE_FORCE_USE_LEGACY_PARAM_IDS is not enabled.
+
+        When adding a parameter that is not present in a previous version of the Audio Unit, you
+        must ensure that the version hint supplied is a number higher than that of any parameter in
+        any previous plugin version.
+
+        For example, in the first release of a plugin, every parameter was created with "1" as a
+        version hint. If you add some parameters in the second release of the plugin, all of the
+        new parameters should have "2" as a version hint. Additional parameters added in subsequent
+        plugin versions should have "3", "4", and so forth, increasing monotonically.
+
+        Note that adding or removing parameters with a version hint that is lower than the maximum
+        version hint of all parameters will break saved automation in some hosts, so be careful!
+
+        A version hint of "0" will be treated as though the version hint has not been set
+        explicitly. When targeting the AU format, the version hint may be checked at runtime in
+        debug builds to ensure that it has been set.
+
+        Rationale:
+
+        According to <a href="https://developer.apple.com/documentation/audiotoolbox/audiounitparameter?language=objc">Apple's Documentation</a>:
+        > An audio unit parameter is uniquely identified by the combination of its scope, element, and ID.
+
+        However, Logic Pro and GarageBand have a known limitation that causes them to use parameter
+        indices instead of IDs to identify parameters. The effect of this is that adding parameters
+        to a later version of a plugin can break automation saved with an earlier version of the
+        plugin if the indices of existing parameters are changed. It is *always* unsafe to remove
+        parameters from an Audio Unit plugin that will be used in one of these hosts, because
+        removing a parameter will always modify the indices of following parameters.
+
+        In order to work around this limitation, parameters in AUv2 plugins are sorted first by
+        their version hint, and then by the hash of their string identifier. As long as the
+        parameters from later versions of the plugin always have a version hint that is higher than
+        the parameters from earlier versions of the plugin, recall of automation data will work as
+        expected in Logic and GarageBand.
+
+        Note that we can't just use the JUCE parameter index directly in order to preserve ordering.
+        This would require all new parameters to be added at the end of the parameter list, which
+        would make it impossible to add parameters to existing parameter groups. It would also make
+        it awkward to structure code sensibly, undoing all of the benefits of string-based parameter
+        identifiers.
+
+        At time of writing, AUv3 plugins seem to be affected by the same issue, but there does not
+        appear to be any API to control parameter indices in this format. Therefore, when building
+        AUv3 plugins you must not add or remove parameters in subsequent plugin versions if you
+        wish to support Logic and GarageBand.
+    */
+    explicit AudioProcessorParameter (int versionHint)
+        : version (versionHint) {}
 
     /** Destructor. */
     virtual ~AudioProcessorParameter();
@@ -176,9 +229,9 @@ public:
 
     enum Category
     {
-        genericParameter = (0 << 16) | 0,        /** If your parameter is not a meter then you should use this category */
+        genericParameter = (0 << 16) | 0,        /**< If your parameter is not a meter then you should use this category */
 
-        inputGain        = (1 << 16) | 0,        /** Currently not used */
+        inputGain        = (1 << 16) | 0,        /**< Currently not used */
         outputGain       = (1 << 16) | 1,
 
         /** The following categories tell the host that this parameter is a meter level value
@@ -222,6 +275,10 @@ public:
     */
     virtual StringArray getAllValueStrings() const;
 
+    //==============================================================================
+    /** @see AudioProcessorParameter(int) */
+    int getVersionHint() const                      { return version; }
+
     //==============================================================================
     /**
         A base class for listeners that want to know about changes to an
@@ -289,6 +346,7 @@ private:
     friend class LegacyAudioParameter;
     AudioProcessor* processor = nullptr;
     int parameterIndex = -1;
+    int version = 0;
     CriticalSection listenerLock;
     Array<Listener*> listeners;
     mutable StringArray valueStrings;
