@@ -2,17 +2,16 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2017 - ROLI Ltd.
+   Copyright (c) 2022 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 5 End-User License
-   Agreement and JUCE 5 Privacy Policy (both updated and effective as of the
-   27th April 2017).
+   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
+   Agreement and JUCE Privacy Policy.
 
-   End User License Agreement: www.juce.com/juce-5-licence
-   Privacy Policy: www.juce.com/juce-5-privacy-policy
+   End User License Agreement: www.juce.com/juce-7-licence
+   Privacy Policy: www.juce.com/juce-privacy-policy
 
    Or: You may also use this code under the terms of the GPL v3 (see
    www.gnu.org/licenses).
@@ -35,5 +34,6 @@ void MouseListener::mouseDrag (const MouseEvent&)  {}
 void MouseListener::mouseMove (const MouseEvent&)  {}
 void MouseListener::mouseDoubleClick (const MouseEvent&) {}
 void MouseListener::mouseWheelMove (const MouseEvent&, const MouseWheelDetails&) {}
+void MouseListener::mouseMagnify (const MouseEvent&, float) {}
 
 } // namespace juce
